# ===============================================================================
# SGraph Send - Transfer ID
# Cryptographically random unique identifier for transfers
# ===============================================================================

from osbot_utils.type_safe.primitives.domains.identifiers.Random_Guid          import Random_Guid


class Transfer_Id(Random_Guid):                                                 # Unique transfer identifier (UUID4)
    pass
